# Yks

### An experiment on setting up a Python project.

[![Build Status](https://travis-ci.com/tonikarppi/yks.svg?branch=master)](https://travis-ci.com/tonikarppi/yks)

This project does not really do anything practical. It's a test for properly configuring a modern Python project with testing and Continuos Integration.

## Installation

This project is available for installation on PyPI.

```
pip install yks
```
